@@ -2,4 +2,4 @@ __name__ = "Suluoya"
 __author__ = 'Suluoya'
 __all__ = ['log']
 
-from .log import sprint, slog, hide, show, progress_bar
+from .log import sprint, slog, hide, show, progress_bar, makedir
