@@ -2,6 +2,6 @@ __name__ = "Suluoya"
 __author__ = 'Suluoya'
 __all__ = ['access', 'pre', 'ai']
 
-from .access import topsis, grey_relation, entropy_weight, entropy_weight_topsis, ladder_distribution, fuzzy_synthesis
+from .assess import topsis, grey_relation, entropy_weight, entropy_weight_topsis, ladder_distribution, fuzzy_synthesis
 from .pre import DataPreprocessor
 from .ai import exploratory_experiment, quantile_regression, linear_regression, logistic_regression
